@@ -1,4 +1,4 @@
-/* $Header: /home/vikas/src/nocol/lib/RCS/bsdsignal.c,v 1.2 1998/07/31 18:20:48 vikas Exp $ */
+/* $Header: /home/vikas/src/nocol/lib/RCS/bsdsignal.c,v 1.3 1999/11/05 21:10:28 vikas Exp $ */
 
 #if defined(SVR4) && !defined(BSDSIGNAL)
 
@@ -11,7 +11,7 @@
 
 #include <signal.h>
 
-void bsdsignal(signo, func)
+void (*bsdsignal(signo, func))
      int signo;
      void *func;
 {
@@ -36,17 +36,17 @@ void bsdsignal(signo, func)
 
     if (sigaction(signo, &act, &oact) < 0) {
 	perror ("bsdsignal (sigaction):");
-/*	return(SIG_ERR);	/* return a value only if not void() */
+	return(SIG_ERR);	/* return a value only if not void() */
     }
-/*    return(oact.sa_handler);	/* return a value only if not void() */
+    return(oact.sa_handler);	/* return a value only if not void() */
 
 }
 
 
 #else	/* SVR4 */
-void bsdsignal ()		/* dummy function to keep linker happy */
+void (*bsdsignal ())		/* dummy function to keep linker happy */
 {
-    return;
+    return (void *)0;
 }
 #endif	/* SVR4 */
 
