@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 #
-# $Header: /home/vikas/src/nocol/perlnocol/RCS/nocollib.pl,v 1.11 1998/08/28 01:12:10 vikas Exp $
+# $Header: /home/vikas/src/nocol/perlnocol/RCS/nocollib.pl,v 1.16 2000/03/28 03:28:43 vikas Exp $
 #
 # 	nocollib.pl - perl library of NOCOL routines
 #
@@ -74,7 +74,7 @@ $rpcping = "$bindir/rpcping" unless $rpcping; # SET_THIS, used by 'hostmon'
 #  Use the utility/show_nocol_struct_sizes to see the size on your arch.
 #  NOTE : Use 'A' instead of 'a' as unpacking 'a' will not remove any
 #  trailing blanks or spaces whereas in case of 'A' it does.
-$event_t = "a11 x a15 x a127 x a15 x L L a7 x  CCCC CC C x" ;
+$event_t = "a11 x a15 x a127 x a15 x L L a7 x  CCCC CC C x" ;	# SET_THIS
 $levent = length( pack($event_t, 0, '') );	    # sizeof structure
 
 if ($libdebug) {
@@ -103,9 +103,8 @@ $varunits      = "UNSET" unless  $varunits;
 $sleepint      = 5*60    unless  $sleepint;
 
 ## these variables are needed by eventlog()
-$nlogfd = -1;
-$nlogclosetime = -1;		# used for deciding when to reopen logfile
-
+$nlogfd = undef;
+$nlogclosetime = 0;		# used for deciding when to reopen logfile
 
 
 ###################################################################
@@ -147,7 +146,13 @@ sub newSocket {
         }
     }
 
-    if ($port =~ /\D/) { $port = getservbyname($port, $sproto); }
+    if ($port == 0 || $port =~ /\D/) {
+      ($junk,$junk,$port) = getservbyname($port, $sproto);
+    }
+    if (! $port) {
+      print STDERR "No port number (is entry needed in /etc/services ?)\n";
+      return undef;
+    }
     if ($sproto =~ /tcp/) { $type = $SOCK_STREAM;}
     else { $type = $SOCK_DGRAM };
 
@@ -158,16 +163,23 @@ sub newSocket {
     }
     else { ($junk,$junk,$junk,$junk, $haddr) = gethostbyname($host); }
 
-    if ($haddr) { ; }
-    else { print STDERR "Unknown host (no address)- $host\n"; return -1; }
+    if (! $haddr) {
+      print STDERR "Unknown host (no address)- $host\n";
+      return undef;
+    }
+
+    unless ($ostype) {$ostype= `uname -s -r -m`; chop ($ostype); }
+    if ($ostype =~ /BSD\/OS\s+4/) { 	# bsdi 4.0 changed socket struct
+      $paddr = pack ('x C n a4 x8', $AF_INET, $port, $haddr);
+    }
+    else { $paddr = pack ('S n a4 x8', $AF_INET, $port, $haddr); }
 
-    $paddr = pack ('S n a4 x8', $AF_INET, $port, $haddr);
     ($junk, $junk, $proto) = getprotobyname($sproto);
     socket(SOCK, $AF_INET, $type, $proto) || die "socket: $!";
     if (! connect(SOCK, $paddr)) {
 	close SOCK;
-	print STDERR "newSocket() connect failed: $!";
-	return -1;
+	print STDERR "newSocket() connect failed: $!\n";
+	return undef;
     }
 
     return (SOCK);
@@ -287,8 +299,8 @@ sub nocol_startup {
     $datafile="$datadir/$me-output" unless $datafile;
 
     $sender= $me unless $sender;	# filled in the EVENT sender
-    $ostype= `uname -s -r -m`  unless $ostype;	# OS, revision, arch
-    chop($ostype);
+    # get OS, revision, arch
+    unless ($ostype) { $ostype= `uname -s -r -m`; chop ($ostype); }
 
     ($libdebug > 1) && print STDERR "(libdebug) me= $me, sender= $sender\n" ;
     if ( (!$debug) && ($p= fork))  {print "$p\n"; exit;}
@@ -304,6 +316,10 @@ sub standalone {
     local($me,$dir)=@_;
     local($localhost)=`hostname`; chop ($localhost);
     local($pid,$host);
+    local($PSCMD) = "/bin/ps";	# cmd to see process by giving a pid
+
+    local ($status) = scalar grep(/usage/i, `$PSCMD 1 2>&1`);
+    if ($status >= 1) { $PSCMD = "/bin/ps -p" ;}	# hope no other flags needed
     
     $pidfile= "$dir/$me.pid";	# cannot be local()
 
@@ -317,7 +333,7 @@ sub standalone {
 	if($pid =~ /^\d+$/)
 	{
 	    for (1..2) {	# try killing twice
-		foreach (`ps $pid`) {
+		foreach (`$PSCMD $pid`) {
 		    chop;
 		    if(/$pid.*$me/){kill(9,$pid); print "killing process $pid\n"; }
 		}			# end: foreach()
@@ -386,6 +402,7 @@ sub calc_status {
     local ($gt) = 1 ;	#  test if value *greater* than thresholds
 
     if ($critt < $warnt) { $gt = 0 ;} # test if value *less* than thres
+    elsif ($critt == $warnt && $critt == 0) { $gt = 0 ;}
 
     if ( ($gt && $val >= $warnt) || ($gt == 0 && $val <= $warnt) ) 
        { $status = 0; }		# value exceeds warning threshold
@@ -455,10 +472,9 @@ sub update_event {
 
 sub eventlog {
     local($event) = @_ ;
-    local($bytesleft);
     local($RETRY_REOPEN) = 1*60 ; # try re-opening logging socket every minute
     
-    if ($nlogfd < 0)
+    if (! defined($nlogfd))
     {
 	local($lport);
 
@@ -470,7 +486,7 @@ sub eventlog {
 	$lport = $NLOG_PORT  unless $lport ;
 
 	$nlogfd = &newSocket($NLOG_HOST, $lport, 'udp');
-	if ($nlogfd < 0) {
+	if (! defined($nlogfd)) {
 	    print STDERR "eventlog- could not connect to $NLOG_HOST\n";
 	    $nlogclosetime = time ;	# record time of last attempt
 	    return (-1);
@@ -481,24 +497,23 @@ sub eventlog {
     }  	# end: if(socket not open)
     
     ## Here only if socket has been opened and have to write out EVENT.
-    $bytesleft = length ($event) ;
-    while ($bytesleft)
+    if (! defined(send($nlogfd, $event, 0)) )
     {
-	local($written);
-	local($offset) = 0;
-        $written = syswrite($nlogfd, $event, $bytesleft, $offset);
-	if ($written <= 0)
-	{
-	    print STDERR ("(libdebug) eventlog syswrite error: $!\n");
-	    close($nlogfd);
-	    $nlogfd = -1;		# reset
-	    return(-1);
-        }
-	
-	$bytesleft -= $written;
-	$offset += $written
-   }			# end:  while($bytesleft)
-}
+      print STDERR ("(libdebug) eventlog send() error: $!");
+      close($nlogfd);
+      undef $nlogfd ;
+      # Try to reopen and resend, since its important. use $nlogclosetime
+      # a flag to prevent endless loop
+      if ($nlogclosetime != 1) {
+	$nlogclosetime = 1;	# prevent looping
+	eventlog($event);
+	$nlogclosetime = 0;
+      }
+      return(-1) if (! defined($nlogfd));
+    }
+
+    return (0);
+}	# eventlog()
 
 
 ##
@@ -560,3 +575,5 @@ sub nocol_main {
 ##
 #
 ##
+
+1;		# needed
