@@ -1,6 +1,6 @@
 #!/usr/local/bin/perl
 #
-# $Header: /home/vikas/src/nocol/webnocol/RCS/genweb.pl,v 1.6 1998/08/28 02:35:01 vikas Exp $ 
+# $Header: /home/vikas/src/nocol/webnocol/RCS/genweb.pl,v 1.11 2000/03/28 04:37:02 vikas Exp $ 
 #
 #			genweb.pl
 # ------------
@@ -69,6 +69,8 @@
 
 #########################################################################
 
+$VERSIONSTR = "4.3.1";		# version
+
 ## Customize $baseurl
 
 ## $baseurl is the URL that will be used to access the nocol HTML files.
@@ -77,7 +79,8 @@ $baseurl = "http://nocol.navya.com";		# SET_THIS
 ## $webdir is the physical path to the directory where the output files
 #  will be generated.
 $webdir  = "/nocol/htmldata";		# SET_THIS
-## $processor points to the nocol.pl CGI script. Used for updating 'updates'
+## $processor points to the webnocol CGI script. Used for updating 'updates'
+#  This is relative to the URL, as seen by the browser.
 $processor = "/cgi-bin/webnocol.cgi";		# SET_THIS
 
 # we have to append a trailing '/' in baseurl if it is specified.
@@ -133,7 +136,9 @@ local ($compactInfo) = 1;	# dont generate Info file in table format
 ($sec, $min, $hour, $mday, $mon, $year,
  $weekday, $yrday, $daylite) = localtime(time);
 $mon++;
-$today = "$z1[$mon]/$z1[$mday]/19$year  $hour:$z1[$min]";
+$year += 1900;	# fix y2k problem
+$today = "$z1[$mon]/$z1[$mday]/$year  $hour:$z1[$min]";	# MMDDYY, us centric
+# $today = "$year/$z1[$mon]/$z1[$mday]  $hour:$z1[$min]";	# YYMMDD
 local($cursecs) = time;	# get Unix timestamp
 
 
@@ -175,7 +180,8 @@ foreach $lvl (@levels) {
   local ($ADMINMODE) = ($lvl eq "User") ? 0 : 1; # No href links for userPage
   $cnt{$lvl} = 1;	# serial number per view
 
-  open (OUTPUT, ">$webdir/${lvl}.html") or die "Unable to open output file $!";
+  open (OUTPUT, ">$webdir/${lvl}.html") or die 
+    "Unable to open output file ($webdir/${lvl}.html) $!";
   select OUTPUT;		# default for print statements
 
   &print_html_prologue($thispage, $lvl, $refresh);
@@ -261,6 +267,19 @@ foreach $dfile (@dfiles)	# process each data file one at a time
     {
       if ( $severity{$i} <= $ilevels{$lvl} )
       {
+	if (defined ($sound) && $sound ne "") {
+	  # set the appropriate warning sound
+	  if ($severity{$i} == $ilevels{"Critical"}) { 
+	    $sound = "critical.wav";
+	  }
+	  if (($severity{$i} == $ilevels{"Error"}) && ($sound ne "critical.wav")) {
+	    $sound = "error.wav";
+	  }
+	  if (($severity{$i} == $ilevels{"Warning"}) &&
+	      (($sound ne "critical.wav") && ($sound ne "error.wav"))) {
+	    $sound = "warning.wav";
+	  }
+	}	# if defined $sound
 	select $lvl;		# default for print statements
 	&print_row($i, $lvl);
 	++$cnt{$lvl} ;
@@ -312,7 +331,7 @@ sub print_html_prologue {
   local ($thispage, $lvl, $refresh) = @_;
 
   local ($action) = $levels[$ilevels{$lvl}];
-  local ($id) = '$Id: genweb.pl,v 1.6 1998/08/28 02:35:01 vikas Exp $';#'
+  local ($id) = '$Id: genweb.pl,v 1.11 2000/03/28 04:37:02 vikas Exp $';#'
 
   $id =~ s/\$//g;	# cleanup
   print <<EOT;
@@ -531,7 +550,7 @@ sub write_msgs {
 sub write_footer {
    ## simple footer
    print "<p><hr width=\"20\%\" shade align=\"left\">\n";
-   print "<font size=\"-2\"><a href=\"http://www.netplex-tech.com/software/nocol\">NOCOL- v2.4.1</a>";
+   print "<font size=\"-2\"><a href=\"http://www.netplex-tech.com/software/nocol\">NOCOL- v$VERSIONSTR</a>";
    print "</body></html>\n";
 
 }
